@@ -3,7 +3,7 @@
 #
 from abc import ABCMeta, abstractmethod
 
-from python_byzatic_commons.flattener.interfaces import FlattenerInterface
+from python_byzatic_commons.flattener.interfaces.FlattenerInterface import FlattenerInterface
 
 
 class DLFlattenerInterface(FlattenerInterface):
